[gimp] Source and trivial typos



commit 69b2e84924e07eb47193f39a490fcf1f9f829cee
Author: luz.paz <luzpaz users noreply github com>
Date:   Sat May 12 12:13:12 2018 -0400

    Source and trivial typos
    
    Found via `codespell` and `grep`

 LICENSE                                     |    2 +-
 app/core/gimpboundary.c                     |    2 +-
 app/core/gimpbrush-private.h                |    4 +-
 app/core/gimpbrush.c                        |   52 +++++++++++++-------------
 app/core/gimpcontext.c                      |    4 +-
 app/core/gimplayer.c                        |    2 +-
 app/display/gimptoolrectangle.c             |    2 +-
 app/operations/gimpcageconfig.c             |    2 +-
 app/pdb/image-cmds.c                        |    8 ++--
 app/tools/gimppainttool-paint.c             |    2 +-
 app/tools/gimptransformtool.c               |    2 +-
 app/widgets/gimpdialogfactory.c             |    2 +-
 libgimp/gimpimage_pdb.c                     |    8 ++--
 libgimpcolor/gimpcolorspace.c               |    2 +-
 libgimpconfig/gimpscanner.c                 |    2 +-
 pdb/groups/image.pdb                        |    8 ++--
 plug-ins/common/curve-bend.c                |    2 +-
 plug-ins/common/file-pix.c                  |    2 +-
 plug-ins/common/file-ps.c                   |    2 +-
 plug-ins/common/sample-colorize.c           |    2 +-
 plug-ins/gfig/gfig-circle.c                 |    2 +-
 plug-ins/gfig/gfig-ellipse.c                |    2 +-
 plug-ins/gfig/gfig-rectangle.c              |    2 +-
 plug-ins/script-fu/scripts/unsharp-mask.scm |   18 +++++-----
 24 files changed, 68 insertions(+), 68 deletions(-)
---
diff --git a/LICENSE b/LICENSE
index 45576b2..79828fc 100644
--- a/LICENSE
+++ b/LICENSE
@@ -9,7 +9,7 @@
   versus a combined or derived work.  The intention is to make it
   clear that arbitrarily-licensed programs such as GIMP plug-ins do
   not automatically assume the GNU General Public License (GPL)
-  themselves simply because of their invokation of (or by) procedures
+  themselves simply because of their invocation of (or by) procedures
   implemented in GPL-licensed code, via libgimp or a similar interface
   to methods provided by the pdb: ]
 
diff --git a/app/core/gimpboundary.c b/app/core/gimpboundary.c
index 4f063b7..a3ec23e 100644
--- a/app/core/gimpboundary.c
+++ b/app/core/gimpboundary.c
@@ -138,7 +138,7 @@ static void       simplify_subdivide  (const GimpBoundSeg  *segs,
  * @x1:        left side of bounds
  * @y1:        top side of bounds
  * @x2:        right side of bounds
- * @y2:        botton side of bounds
+ * @y2:        bottom side of bounds
  * @threshold: pixel value of boundary line
  * @num_segs:  number of returned #GimpBoundSeg's
  *
diff --git a/app/core/gimpbrush.c b/app/core/gimpbrush.c
index 12359c8..5574763 100644
--- a/app/core/gimpbrush.c
+++ b/app/core/gimpbrush.c
@@ -184,8 +184,8 @@ gimp_brush_finalize (GObject *object)
 
   g_clear_pointer (&brush->priv->mask,          gimp_temp_buf_unref);
   g_clear_pointer (&brush->priv->pixmap,        gimp_temp_buf_unref);
-  g_clear_pointer (&brush->priv->blured_mask,   gimp_temp_buf_unref);
-  g_clear_pointer (&brush->priv->blured_pixmap, gimp_temp_buf_unref);
+  g_clear_pointer (&brush->priv->blurred_mask,   gimp_temp_buf_unref);
+  g_clear_pointer (&brush->priv->blurred_pixmap, gimp_temp_buf_unref);
 
   g_clear_object (&brush->priv->mask_cache);
   g_clear_object (&brush->priv->pixmap_cache);
@@ -398,8 +398,8 @@ gimp_brush_dirty (GimpData *data)
   if (brush->priv->boundary_cache)
     gimp_brush_cache_clear (brush->priv->boundary_cache);
 
-  g_clear_pointer (&brush->priv->blured_mask,   gimp_temp_buf_unref);
-  g_clear_pointer (&brush->priv->blured_pixmap, gimp_temp_buf_unref);
+  g_clear_pointer (&brush->priv->blurred_mask,   gimp_temp_buf_unref);
+  g_clear_pointer (&brush->priv->blurred_pixmap, gimp_temp_buf_unref);
 
   GIMP_DATA_CLASS (parent_class)->dirty (data);
 }
@@ -430,8 +430,8 @@ gimp_brush_real_end_use (GimpBrush *brush)
   g_clear_object (&brush->priv->pixmap_cache);
   g_clear_object (&brush->priv->boundary_cache);
 
-  g_clear_pointer (&brush->priv->blured_mask,   gimp_temp_buf_unref);
-  g_clear_pointer (&brush->priv->blured_pixmap, gimp_temp_buf_unref);
+  g_clear_pointer (&brush->priv->blurred_mask,   gimp_temp_buf_unref);
+  g_clear_pointer (&brush->priv->blurred_pixmap, gimp_temp_buf_unref);
 }
 
 static GimpBrush *
@@ -629,12 +629,12 @@ gimp_brush_transform_mask (GimpBrush *brush,
        * (all of them but generated) are blurred once and no more.
        * It also makes hardnes dynamics not work for these brushes.
        * This is intentional. Confoliving for each stamp is too expensive.*/
-      if (! brush->priv->blured_mask &&
+      if (! brush->priv->blurred_mask &&
           ! GIMP_IS_BRUSH_GENERATED(brush) &&
           ! GIMP_IS_BRUSH_PIPE(brush) && /*Can't cache pipes. Sanely anyway*/
           hardness < 1.0)
         {
-           brush->priv->blured_mask = GIMP_BRUSH_GET_CLASS (brush)->transform_mask (brush,
+           brush->priv->blurred_mask = GIMP_BRUSH_GET_CLASS (brush)->transform_mask (brush,
                                                              1.0,
                                                              0.0,
                                                              0.0,
@@ -643,7 +643,7 @@ gimp_brush_transform_mask (GimpBrush *brush,
            brush->priv->blur_hardness = hardness;
         }
 
-      if (brush->priv->blured_mask)
+      if (brush->priv->blurred_mask)
         {
           effective_hardness = 1.0; /*Hardness has already been applied*/
         }
@@ -722,12 +722,12 @@ gimp_brush_transform_pixmap (GimpBrush *brush,
   if (! pixmap)
     {
 #if 0
-     if (! brush->priv->blured_pixmap &&
+     if (! brush->priv->blurred_pixmap &&
          ! GIMP_IS_BRUSH_GENERATED(brush) &&
          ! GIMP_IS_BRUSH_PIPE(brush) /*Can't cache pipes. Sanely anyway*/
          && hardness < 1.0)
       {
-         brush->priv->blured_pixmap = GIMP_BRUSH_GET_CLASS (brush)->transform_pixmap (brush,
+         brush->priv->blurred_pixmap = GIMP_BRUSH_GET_CLASS (brush)->transform_pixmap (brush,
                                                                   1.0,
                                                                   0.0,
                                                                   0.0,
@@ -736,7 +736,7 @@ gimp_brush_transform_pixmap (GimpBrush *brush,
          brush->priv->blur_hardness = hardness;
        }
 
-      if (brush->priv->blured_pixmap) {
+      if (brush->priv->blurred_pixmap) {
         effective_hardness = 1.0; /*Hardness has already been applied*/
       }
 #endif
@@ -842,9 +842,9 @@ gimp_brush_get_mask (GimpBrush *brush)
   g_return_val_if_fail (brush != NULL, NULL);
   g_return_val_if_fail (GIMP_IS_BRUSH (brush), NULL);
 
-  if (brush->priv->blured_mask)
+  if (brush->priv->blurred_mask)
     {
-      return brush->priv->blured_mask;
+      return brush->priv->blurred_mask;
     }
   return brush->priv->mask;
 }
@@ -855,9 +855,9 @@ gimp_brush_get_pixmap (GimpBrush *brush)
   g_return_val_if_fail (brush != NULL, NULL);
   g_return_val_if_fail (GIMP_IS_BRUSH (brush), NULL);
 
-  if(brush->priv->blured_pixmap)
+  if(brush->priv->blurred_pixmap)
     {
-      return brush->priv->blured_pixmap;
+      return brush->priv->blurred_pixmap;
     }
   return brush->priv->pixmap;
 }
@@ -866,8 +866,8 @@ void
 gimp_brush_flush_blur_caches (GimpBrush *brush)
 {
 #if 0
-  g_clear_pointer (&brush->priv->blured_mask,   gimp_temp_buf_unref);
-  g_clear_pointer (&brush->priv->blured_pixmap, gimp_temp_buf_unref);
+  g_clear_pointer (&brush->priv->blurred_mask,   gimp_temp_buf_unref);
+  g_clear_pointer (&brush->priv->blurred_pixmap, gimp_temp_buf_unref);
 
   if (brush->priv->mask_cache)
     gimp_brush_cache_clear (brush->priv->mask_cache);
@@ -893,11 +893,11 @@ gimp_brush_get_width (GimpBrush *brush)
 {
   g_return_val_if_fail (GIMP_IS_BRUSH (brush), 0);
 
-  if (brush->priv->blured_mask)
-    return gimp_temp_buf_get_width (brush->priv->blured_mask);
+  if (brush->priv->blurred_mask)
+    return gimp_temp_buf_get_width (brush->priv->blurred_mask);
 
-  if (brush->priv->blured_pixmap)
-    return gimp_temp_buf_get_width (brush->priv->blured_pixmap);
+  if (brush->priv->blurred_pixmap)
+    return gimp_temp_buf_get_width (brush->priv->blurred_pixmap);
 
   return gimp_temp_buf_get_width (brush->priv->mask);
 }
@@ -907,11 +907,11 @@ gimp_brush_get_height (GimpBrush *brush)
 {
   g_return_val_if_fail (GIMP_IS_BRUSH (brush), 0);
 
-  if (brush->priv->blured_mask)
-    return gimp_temp_buf_get_height (brush->priv->blured_mask);
+  if (brush->priv->blurred_mask)
+    return gimp_temp_buf_get_height (brush->priv->blurred_mask);
 
-  if (brush->priv->blured_pixmap)
-    return gimp_temp_buf_get_height (brush->priv->blured_pixmap);
+  if (brush->priv->blurred_pixmap)
+    return gimp_temp_buf_get_height (brush->priv->blurred_pixmap);
 
   return gimp_temp_buf_get_height (brush->priv->mask);
 }
diff --git a/app/core/gimpcontext.c b/app/core/gimpcontext.c
index 3f2d3cf..b4f79da 100644
--- a/app/core/gimpcontext.c
+++ b/app/core/gimpcontext.c
@@ -215,12 +215,12 @@ static void gimp_context_real_set_gradient   (GimpContext      *context,
 static void gimp_context_palette_dirty       (GimpPalette      *palette,
                                               GimpContext      *context);
 static void gimp_context_palette_removed     (GimpContainer    *container,
-                                              GimpPalette      *palatte,
+                                              GimpPalette      *palette,
                                               GimpContext      *context);
 static void gimp_context_palette_list_thaw   (GimpContainer    *container,
                                               GimpContext      *context);
 static void gimp_context_real_set_palette    (GimpContext      *context,
-                                              GimpPalette      *palatte);
+                                              GimpPalette      *palette);
 
 /*  tool preset  */
 static void gimp_context_tool_preset_dirty     (GimpToolPreset   *tool_preset,
diff --git a/app/core/gimplayer.c b/app/core/gimplayer.c
index d5e3106..810f570 100644
--- a/app/core/gimplayer.c
+++ b/app/core/gimplayer.c
@@ -656,7 +656,7 @@ gimp_layer_dispose (GObject *object)
       GimpDrawable *fs_drawable = gimp_layer_get_floating_sel_drawable (layer);
 
       /* only detach if this is actually the drawable's fs because the
-       * layer might be on the undo stack and not attached to anyhing
+       * layer might be on the undo stack and not attached to anything
        */
       if (gimp_drawable_get_floating_sel (fs_drawable) == layer)
         gimp_drawable_detach_floating_sel (fs_drawable);
diff --git a/app/display/gimptoolrectangle.c b/app/display/gimptoolrectangle.c
index 3836ec2..fcfe5fb 100644
--- a/app/display/gimptoolrectangle.c
+++ b/app/display/gimptoolrectangle.c
@@ -3937,7 +3937,7 @@ gimp_tool_rectangle_pending_size_set (GimpToolRectangle *rectangle,
  * @height_property: Option property to set to current constraint height.
  *
  * Sets specified rectangle tool options properties to the width and
- * height of the current contraint size.
+ * height of the current constraint size.
  */
 void
 gimp_tool_rectangle_constraint_size_set (GimpToolRectangle *rectangle,
diff --git a/app/operations/gimpcageconfig.c b/app/operations/gimpcageconfig.c
index 29677f8..333430c 100644
--- a/app/operations/gimpcageconfig.c
+++ b/app/operations/gimpcageconfig.c
@@ -334,7 +334,7 @@ gimp_cage_config_get_point_coordinate (GimpCageConfig *gcc,
  * @x: x displacement value
  * @y: y displacement value
  *
- * Add a displacement for all slected point of the cage.
+ * Add a displacement for all selected points of the cage.
  * This displacement need to be committed to become effective.
  */
 void
diff --git a/app/pdb/image-cmds.c b/app/pdb/image-cmds.c
index 7dd4670..318620a 100644
--- a/app/pdb/image-cmds.c
+++ b/app/pdb/image-cmds.c
@@ -3755,7 +3755,7 @@ register_image_procs (GimpPDB *pdb)
   gimp_procedure_set_static_strings (procedure,
                                      "gimp-image-freeze-layers",
                                      "Freeze the image's layer list.",
-                                     "This procedure freezes the layer list of the image, supressing any 
updates to the Layers dialog in response to changes to the image's layers. This can significantly improve 
performance while applying changes affecting the layer list.\n"
+                                     "This procedure freezes the layer list of the image, suppressing any 
updates to the Layers dialog in response to changes to the image's layers. This can significantly improve 
performance while applying changes affecting the layer list.\n"
                                      "\n"
                                      "Each call to 'gimp-image-freeze-layers' should be matched by a 
corresponding call to 'gimp-image-thaw-layers', undoing its effects.",
                                      "Ell",
@@ -3910,7 +3910,7 @@ register_image_procs (GimpPDB *pdb)
   gimp_procedure_set_static_strings (procedure,
                                      "gimp-image-freeze-channels",
                                      "Freeze the image's channel list.",
-                                     "This procedure freezes the channel list of the image, supressing any 
updates to the Channels dialog in response to changes to the image's channels. This can significantly improve 
performance while applying changes affecting the channel list.\n"
+                                     "This procedure freezes the channel list of the image, suppressing any 
updates to the Channels dialog in response to changes to the image's channels. This can significantly improve 
performance while applying changes affecting the channel list.\n"
                                      "\n"
                                      "Each call to 'gimp-image-freeze-channels' should be matched by a 
corresponding call to 'gimp-image-thaw-channels', undoing its effects.",
                                      "Ell",
@@ -3937,7 +3937,7 @@ register_image_procs (GimpPDB *pdb)
                                      "Thaw the image's channel list.",
                                      "This procedure thaws the channel list of the image, re-enabling 
updates to the Channels dialog.\n"
                                      "\n"
-                                     "This procedure should match a corresponing call to 
'gimp-image-freeze-channels'.",
+                                     "This procedure should match a corresponding call to 
'gimp-image-freeze-channels'.",
                                      "Ell",
                                      "Ell",
                                      "2018",
@@ -4065,7 +4065,7 @@ register_image_procs (GimpPDB *pdb)
   gimp_procedure_set_static_strings (procedure,
                                      "gimp-image-freeze-vectors",
                                      "Freeze the image's vectors list.",
-                                     "This procedure freezes the vectors list of the image, supressing any 
updates to the Paths dialog in response to changes to the image's vectors. This can significantly improve 
performance while applying changes affecting the vectors list.\n"
+                                     "This procedure freezes the vectors list of the image, suppressing any 
updates to the Paths dialog in response to changes to the image's vectors. This can significantly improve 
performance while applying changes affecting the vectors list.\n"
                                      "\n"
                                      "Each call to 'gimp-image-freeze-vectors' should be matched by a 
corresponding call to 'gimp-image-thaw-vectors', undoing its effects.",
                                      "Ell",
diff --git a/app/tools/gimppainttool-paint.c b/app/tools/gimppainttool-paint.c
index cf64b8d..96754ff 100644
--- a/app/tools/gimppainttool-paint.c
+++ b/app/tools/gimppainttool-paint.c
@@ -269,7 +269,7 @@ gimp_paint_tool_paint_start (GimpPaintTool     *paint_tool,
 
   if ((display != tool->display) || ! paint_tool->draw_line)
     {
-      /*  If this is a new display, resest the "last stroke's endpoint"
+      /*  If this is a new display, reset the "last stroke's endpoint"
        *  because there is none
        */
       if (display != tool->display)
diff --git a/app/tools/gimptransformtool.c b/app/tools/gimptransformtool.c
index 6673e7e..e43337c 100644
--- a/app/tools/gimptransformtool.c
+++ b/app/tools/gimptransformtool.c
@@ -267,7 +267,7 @@ gimp_transform_tool_initialize (GimpTool     *tool,
   if (! tr_tool->gui)
     gimp_transform_tool_dialog (tr_tool);
 
-  /*  Inizialize the tool-specific trans_info, and adjust the tool dialog  */
+  /*  Initialize the tool-specific trans_info, and adjust the tool dialog  */
   gimp_transform_tool_prepare (tr_tool, display);
 
   /*  Recalculate the transform tool  */
diff --git a/app/widgets/gimpdialogfactory.c b/app/widgets/gimpdialogfactory.c
index c8f5fce..2ded10d 100644
--- a/app/widgets/gimpdialogfactory.c
+++ b/app/widgets/gimpdialogfactory.c
@@ -473,7 +473,7 @@ gimp_dialog_factory_dialog_new_internal (GimpDialogFactory *factory,
       return NULL;
     }
 
-  /*  a singleton dialog is always returned if it already exisits  */
+  /*  a singleton dialog is always returned if it already exists  */
   if (return_existing || entry->singleton)
     {
       dialog = gimp_dialog_factory_find_widget (factory, identifier);
diff --git a/libgimp/gimpimage_pdb.c b/libgimp/gimpimage_pdb.c
index 47d9252..22944a8 100644
--- a/libgimp/gimpimage_pdb.c
+++ b/libgimp/gimpimage_pdb.c
@@ -933,7 +933,7 @@ gimp_image_remove_layer (gint32 image_ID,
  *
  * Freeze the image's layer list.
  *
- * This procedure freezes the layer list of the image, supressing any
+ * This procedure freezes the layer list of the image, suppressing any
  * updates to the Layers dialog in response to changes to the image's
  * layers. This can significantly improve performance while applying
  * changes affecting the layer list.
@@ -1114,7 +1114,7 @@ gimp_image_remove_channel (gint32 image_ID,
  *
  * Freeze the image's channel list.
  *
- * This procedure freezes the channel list of the image, supressing any
+ * This procedure freezes the channel list of the image, suppressing any
  * updates to the Channels dialog in response to changes to the image's
  * channels. This can significantly improve performance while applying
  * changes affecting the channel list.
@@ -1155,7 +1155,7 @@ gimp_image_freeze_channels (gint32 image_ID)
  * This procedure thaws the channel list of the image, re-enabling
  * updates to the Channels dialog.
  *
- * This procedure should match a corresponing call to
+ * This procedure should match a corresponding call to
  * gimp_image_freeze_channels().
  *
  * Returns: TRUE on success.
@@ -1298,7 +1298,7 @@ gimp_image_remove_vectors (gint32 image_ID,
  *
  * Freeze the image's vectors list.
  *
- * This procedure freezes the vectors list of the image, supressing any
+ * This procedure freezes the vectors list of the image, suppressing any
  * updates to the Paths dialog in response to changes to the image's
  * vectors. This can significantly improve performance while applying
  * changes affecting the vectors list.
diff --git a/libgimpcolor/gimpcolorspace.c b/libgimpcolor/gimpcolorspace.c
index e5d4864..aca6273 100644
--- a/libgimpcolor/gimpcolorspace.c
+++ b/libgimpcolor/gimpcolorspace.c
@@ -771,7 +771,7 @@ gimp_rgb_to_hsl_int (gint *red,
  * Calculates the lightness value of an RGB triplet with the formula
  * L = (max(R, G, B) + min (R, G, B)) / 2
  *
- * Return value: Luminance vaue corresponding to the input RGB value
+ * Return value: Luminance value corresponding to the input RGB value
  **/
 gint
 gimp_rgb_to_l_int (gint red,
diff --git a/libgimpconfig/gimpscanner.c b/libgimpconfig/gimpscanner.c
index 740a458..c82a7ea 100644
--- a/libgimpconfig/gimpscanner.c
+++ b/libgimpconfig/gimpscanner.c
@@ -450,7 +450,7 @@ gimp_scanner_parse_string_no_validate (GScanner  *scanner,
  * gimp_scanner_parse_data:
  * @scanner: A #GScanner created by gimp_scanner_new_file() or
  *           gimp_scanner_new_string()
- * @length: Length of tha data to parse
+ * @length: Length of the data to parse
  * @dest: Return location for the parsed data
  *
  * Return value: %TRUE on success
diff --git a/pdb/groups/image.pdb b/pdb/groups/image.pdb
index 940afab..abf862c 100644
--- a/pdb/groups/image.pdb
+++ b/pdb/groups/image.pdb
@@ -1023,7 +1023,7 @@ sub image_freeze_layers {
     $blurb = "Freeze the image's layer list.";
 
     $help = <<'HELP';
-This procedure freezes the layer list of the image, supressing any
+This procedure freezes the layer list of the image, suppressing any
 updates to the Layers dialog in response to changes to the image's
 layers.  This can significantly improve performance while applying
 changes affecting the layer list.
@@ -1205,7 +1205,7 @@ sub image_freeze_channels {
     &ell_pdb_misc('2018', '2.10');
 
     $help = <<'HELP';
-This procedure freezes the channel list of the image, supressing any
+This procedure freezes the channel list of the image, suppressing any
 updates to the Channels dialog in response to changes to the image's
 channels.  This can significantly improve performance while applying
 changes affecting the channel list.
@@ -1247,7 +1247,7 @@ This procedure thaws the channel list of the image, re-enabling
 updates to the Channels dialog.
 
 
-This procedure should match a corresponing call to
+This procedure should match a corresponding call to
 gimp_image_freeze_channels().
 HELP
 
@@ -1383,7 +1383,7 @@ sub image_freeze_vectors {
     &ell_pdb_misc('2018', '2.10');
 
     $help = <<'HELP';
-This procedure freezes the vectors list of the image, supressing any
+This procedure freezes the vectors list of the image, suppressing any
 updates to the Paths dialog in response to changes to the image's
 vectors.  This can significantly improve performance while applying
 changes affecting the vectors list.
diff --git a/plug-ins/common/curve-bend.c b/plug-ins/common/curve-bend.c
index 1d067e4..19ee70e 100644
--- a/plug-ins/common/curve-bend.c
+++ b/plug-ins/common/curve-bend.c
@@ -2795,7 +2795,7 @@ p_add_layer (gint       width,
   /* add the copied layer to the temp. working image */
   gimp_image_insert_layer (image_id, l_new_layer_id, -1, stack_position);
 
-  /* copy visiblity state */
+  /* copy visibility state */
   gimp_item_set_visible (l_new_layer_id, l_visible);
 
   return l_new_drawable;
diff --git a/plug-ins/common/file-pix.c b/plug-ins/common/file-pix.c
index 4fc376d..b4608fb 100644
--- a/plug-ins/common/file-pix.c
+++ b/plug-ins/common/file-pix.c
@@ -219,7 +219,7 @@ run (const gchar      *name,
         }
       else
         {
-          /* The image load falied */
+          /* The image load failed */
           status = GIMP_PDB_EXECUTION_ERROR;
         }
     }
diff --git a/plug-ins/common/file-ps.c b/plug-ins/common/file-ps.c
index f76e377..e39972e 100644
--- a/plug-ins/common/file-ps.c
+++ b/plug-ins/common/file-ps.c
@@ -1482,7 +1482,7 @@ static char *psfgets (char *s, int size, FILE *stream)
           *(sptr++) = '\n';
           break;
         }
-      else if (c == '\r')  /* Got a carriage return. Check next charcater */
+      else if (c == '\r')  /* Got a carriage return. Check next character */
         {
           c = getc (stream);
           if ((c == EOF) || (c == '\n')) /* EOF or DOS line end ? */
diff --git a/plug-ins/common/sample-colorize.c b/plug-ins/common/sample-colorize.c
index 56ab030..547edb0 100644
--- a/plug-ins/common/sample-colorize.c
+++ b/plug-ins/common/sample-colorize.c
@@ -2457,7 +2457,7 @@ fill_missing_colors (void)
     }
 }
 
-/* get 256 samples of active gradient (optional in invers order) */
+/* get 256 samples of active gradient (optional in inverse order) */
 static void
 get_gradient (gint mode)
 {
diff --git a/plug-ins/gfig/gfig-circle.c b/plug-ins/gfig/gfig-circle.c
index a8c9d11..b23b764 100644
--- a/plug-ins/gfig/gfig-circle.c
+++ b/plug-ins/gfig/gfig-circle.c
@@ -218,7 +218,7 @@ void
 d_circle_end (GdkPoint *pnt,
               gboolean  shift_down)
 {
-  /* Under contrl point */
+  /* Under control point */
   if (!obj_creating->points->next)
     {
       /* No circle created */
diff --git a/plug-ins/gfig/gfig-ellipse.c b/plug-ins/gfig/gfig-ellipse.c
index 405f21c..9cff368 100644
--- a/plug-ins/gfig/gfig-ellipse.c
+++ b/plug-ins/gfig/gfig-ellipse.c
@@ -219,7 +219,7 @@ void
 d_ellipse_end (GdkPoint *pnt,
                gboolean  shift_down)
 {
-  /* Under contrl point */
+  /* Under control point */
   if (!obj_creating->points->next)
     {
       /* No circle created */
diff --git a/plug-ins/gfig/gfig-rectangle.c b/plug-ins/gfig/gfig-rectangle.c
index e0df2d7..3fe7acb 100644
--- a/plug-ins/gfig/gfig-rectangle.c
+++ b/plug-ins/gfig/gfig-rectangle.c
@@ -202,7 +202,7 @@ void
 d_rectangle_end (GdkPoint *pnt,
                  gboolean  shift_down)
 {
-  /* Under contrl point */
+  /* Under control point */
   if (!obj_creating->points->next)
     {
       /* No circle created */
diff --git a/plug-ins/script-fu/scripts/unsharp-mask.scm b/plug-ins/script-fu/scripts/unsharp-mask.scm
index 7972ab6..77daf82 100644
--- a/plug-ins/script-fu/scripts/unsharp-mask.scm
+++ b/plug-ins/script-fu/scripts/unsharp-mask.scm
@@ -14,8 +14,8 @@
                                              100 LAYER-MODE-NORMAL)))
         (original-layer-for-darker 0)
         (original-layer-for-lighter 0)
-        (blured-layer-for-darker 0)
-        (blured-layer-for-lighter 0)
+        (blurred-layer-for-darker 0)
+        (blurred-layer-for-lighter 0)
         (darker-layer 0)
         (lighter-layer 0)
         )
@@ -31,16 +31,16 @@
 
     (set! original-layer-for-darker (car (gimp-layer-copy original-layer TRUE)))
     (set! original-layer-for-lighter (car (gimp-layer-copy original-layer TRUE)))
-    (set! blured-layer-for-darker (car (gimp-layer-copy original-layer TRUE)))
+    (set! blurred-layer-for-darker (car (gimp-layer-copy original-layer TRUE)))
     (gimp-item-set-visible original-layer FALSE)
     (gimp-display-new new-image)
 
     ;; make darker mask
-    (gimp-image-insert-layer new-image blured-layer-for-darker 0 -1)
+    (gimp-image-insert-layer new-image blurred-layer-for-darker 0 -1)
     (plug-in-gauss-iir RUN-NONINTERACTIVE
-                      new-image blured-layer-for-darker mask-size TRUE TRUE)
-    (set! blured-layer-for-lighter
-          (car (gimp-layer-copy blured-layer-for-darker TRUE)))
+                      new-image blurred-layer-for-darker mask-size TRUE TRUE)
+    (set! blurred-layer-for-lighter
+          (car (gimp-layer-copy blurred-layer-for-darker TRUE)))
     (gimp-image-insert-layer new-image original-layer-for-darker 0 -1)
     (gimp-layer-set-mode original-layer-for-darker LAYER-MODE-SUBTRACT)
     (set! darker-layer
@@ -50,8 +50,8 @@
 
     ;; make lighter mask
     (gimp-image-insert-layer new-image original-layer-for-lighter 0 -1)
-    (gimp-image-insert-layer new-image blured-layer-for-lighter 0 -1)
-    (gimp-layer-set-mode blured-layer-for-lighter LAYER-MODE-SUBTRACT)
+    (gimp-image-insert-layer new-image blurred-layer-for-lighter 0 -1)
+    (gimp-layer-set-mode blurred-layer-for-lighter LAYER-MODE-SUBTRACT)
     (set! lighter-layer
           (car (gimp-image-merge-visible-layers new-image CLIP-TO-IMAGE)))
     (gimp-item-set-name lighter-layer "lighter mask")


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/app/core/gimpbrush-private.h b/app/core/gimpbrush-private.h
index 801a31b..2a5f91f 100644
--- a/app/core/gimpbrush-private.h
+++ b/app/core/gimpbrush-private.h
@@ -22,9 +22,9 @@
 struct _GimpBrushPrivate
 {
   GimpTempBuf    *mask;           /*  the actual mask                    */
-  GimpTempBuf    *blured_mask;    /*  blured actual mask cached          */
+  GimpTempBuf    *blurred_mask;    /*  blurred actual mask cached          */
   GimpTempBuf    *pixmap;         /*  optional pixmap data               */
-  GimpTempBuf    *blured_pixmap;  /*  optional pixmap data blured cache  */
+  GimpTempBuf    *blurred_pixmap;  /*  optional pixmap data blurred cache  */
 
   gdouble         blur_hardness;
 